@@ -7,8 +7,9 @@
 #
 #######################################################################
 
-from cryptdomainmgr.cdmconfighandler import *
-from cryptdomainmgr.cdmstatehandler import *
+from cryptdomainmgr.cdmconfighandler import ConfigReader
+from cryptdomainmgr.cdmstatehandler import StateHandler
+#from cryptdomainmgr.modules.common.cdmconfighelper import getStateDir
 from simpleloggerplus import simpleloggerplus as log
 
 def getNextPhase(currentPhase):
@@ -25,7 +26,10 @@ def getCurrentPhase(state, forcePhase='next'):
         return state.result['nextphase']
     return 'prepare'
 
-
+# maybe ToDo: readConfig() -> addConfig() + setConfig()
+# run() with explicit parameter to overwrite config
+# option to mix config files and config content in the priority list
+# INFO about config files and content read
 class ManagedDomain:
     def __init__(self):
         self.cr = ConfigReader()
@@ -41,7 +45,8 @@ class ManagedDomain:
         self.sh.registerConfig(self.cr.config['cdm'])
 
     def run(self, confFile=None, forcePhase='next', confContent=''):
-        self.readConfig(confFile, confContent)
+        if confFile is not None or 0 < len(confContent):
+            self.readConfig(confFile, confContent)
         self.sh.load()
         self.sh.delete() # --next starts with prepare, if failed
         self.sh.resetOpStateRecursive()
